.. _negative-patterns:

Negative Patterns in DDD
========================

1. Anemic Model
---------------

This is where you are using an object-oriented domain model, and all of your Aggregates have only public accessors (getters and setters) but no real business behavior. This tends to happen when there is a technical rather than business focus during modeling. Designing an Anemic Domain Model requires you to take on all the overhead of a domain model without realizing any of its benefits.

2. ACID transactions
--------------------

<WIP>

3. Abstraction or DRYing code
-----------------------------

<WIP>
